@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013-2015  Rinat Ibragimov
+ * Copyright © 2013-2017  Rinat Ibragimov
  *
  * This file is part of FreshPlayerPlugin.
  *
@@ -23,16 +23,21 @@
  */
 
 #include "audio_thread.h"
-#include <asoundlib.h>
-#include <pthread.h>
-#include <glib.h>
-#include <unistd.h>
-#include "trace.h"
 #include "config.h"
-#include "utils.h"
 #include "eintr_retry.h"
 #include "ppb_message_loop.h"
-
+#include "trace_core.h"
+#include "trace_helpers.h"
+#include "utils.h"
+#include <asoundlib.h>
+#include <errno.h>
+#include <glib.h>
+#include <poll.h>
+#include <pthread.h>
+#include <stdint.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
 
 struct audio_stream_s {
     audio_stream_direction      direction;
@@ -386,8 +391,8 @@ alsa_create_stream(audio_stream_direction direction, unsigned int sample_rate,
 
     unsigned int period_time = (long long)sample_frame_count * 1000 * 1000 / sample_rate;
     period_time = CLAMP(period_time,
-                        1000 * config.audio_buffer_min_ms,
-                        1000 * config.audio_buffer_max_ms);
+                        1000 * (unsigned int)config.audio_buffer_min_ms,
+                        1000 * (unsigned int)config.audio_buffer_max_ms);
     dir = 1;
     CHECK_A(snd_pcm_hw_params_set_period_time_near, (as->pcm, hw_params, &period_time, &dir));
 
