@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013-2015  Rinat Ibragimov
+ * Copyright © 2013-2017  Rinat Ibragimov
  *
  * This file is part of FreshPlayerPlugin.
  *
@@ -27,17 +27,24 @@
  */
 
 #include "p2n_proxy_class.h"
-#include "trace.h"
-#include "tables.h"
-#include <ppapi/c/private/ppp_instance_private.h>
-#include <ppapi/c/pp_errors.h>
-#include "pp_interface.h"
-#include "pp_resource.h"
-#include "ppb_var.h"
 #include "ppb_core.h"
 #include "ppb_message_loop.h"
-#include "n2p_proxy_class.h"
-
+#include "ppb_var.h"
+#include "tables.h"
+#include "trace_core.h"
+#include "utils.h"
+#include <glib.h>
+#include <npapi/npapi.h>
+#include <npapi/npfunctions.h>
+#include <npapi/npruntime.h>
+#include <ppapi/c/pp_bool.h>
+#include <ppapi/c/pp_errors.h>
+#include <ppapi/c/pp_resource.h>
+#include <ppapi/c/pp_var.h>
+#include <stdbool.h>
+#include <stdint.h>
+#include <stdlib.h>
+#include <string.h>
 
 NPObject *
 p2n_allocate(NPP npp, NPClass *aClass)
