@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013-2015  Rinat Ibragimov
+ * Copyright © 2013-2017  Rinat Ibragimov
  *
  * This file is part of FreshPlayerPlugin.
  *
@@ -22,9 +22,7 @@
  * SOFTWARE.
  */
 
-#ifndef FPP_PP_INTERFACE_H
-#define FPP_PP_INTERFACE_H
-
+#pragma once
 
 extern const void *(*ppp_get_interface)(const char *interface_name);
 
@@ -33,5 +31,3 @@ ppb_get_interface(const char *interface_name);
 
 void
 register_interface(const char *name, const void *implementation);
-
-#endif // FPP_PP_INTERFACE_H
