@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013-2015  Rinat Ibragimov
+ * Copyright © 2013-2017  Rinat Ibragimov
  *
  * This file is part of FreshPlayerPlugin.
  *
@@ -22,18 +22,34 @@
  * SOFTWARE.
  */
 
-#include "ppb_audio_input.h"
-#include "ppb_device_ref.h"
-#include "ppb_var.h"
-#include <stdlib.h>
-#include <ppapi/c/pp_errors.h>
-#include "ppb_core.h"
-#include "pp_resource.h"
+#include "audio_thread.h"
 #include "pp_interface.h"
-#include "trace.h"
-#include "tables.h"
+#include "pp_resource.h"
+#include "ppb_audio_config.h"
+#include "ppb_audio_input.h"
+#include "ppb_core.h"
+#include "ppb_device_ref.h"
+#include "ppb_instance.h"
 #include "ppb_message_loop.h"
+#include "ppb_var.h"
+#include "static_assert.h"
+#include "tables.h"
+#include "trace_core.h"
+#include <ppapi/c/pp_errors.h>
+#include <stdlib.h>
 
+struct pp_audio_input_s {
+    COMMON_STRUCTURE_FIELDS
+    uint32_t                    sample_rate;
+    uint32_t                    sample_frame_count;
+    PPB_AudioInput_Callback_0_3 cb_0_3;
+    PPB_AudioInput_Callback     cb_0_4;
+    void                       *cb_user_data;
+    audio_stream_ops           *stream_ops;
+    audio_stream               *stream;
+};
+
+STATIC_ASSERT(sizeof(struct pp_audio_input_s) <= LARGEST_RESOURCE_SIZE);
 
 PP_Resource
 ppb_audio_input_create(PP_Instance instance)
