@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013-2015  Rinat Ibragimov
+ * Copyright © 2013-2017  Rinat Ibragimov
  *
  * This file is part of FreshPlayerPlugin.
  *
@@ -22,13 +22,9 @@
  * SOFTWARE.
  */
 
-#ifndef FPP_PPB_CRYPTO_H
-#define FPP_PPB_CRYPTO_H
+#pragma once
 
 #include <ppapi/c/dev/ppb_crypto_dev.h>
 
-
 void
 ppb_crypto_get_random_bytes(char *buffer, uint32_t num_bytes);
-
-#endif // FPP_PPB_CRYPTO_H
