@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013-2015  Rinat Ibragimov
+ * Copyright © 2013-2017  Rinat Ibragimov
  *
  * This file is part of FreshPlayerPlugin.
  *
@@ -22,13 +22,11 @@
  * SOFTWARE.
  */
 
-#ifndef FPP_PPB_OPENGLES2_H
-#define FPP_PPB_OPENGLES2_H
+#pragma once
 
 #include <GLES2/gl2.h>
 #include <ppapi/c/ppb_opengles2.h>
 
-
 void
 ppb_opengles2_ActiveTexture(PP_Resource context, GLenum texture);
 
@@ -568,5 +566,3 @@ ppb_opengles2_query_get_queryiv_ext(PP_Resource context, GLenum target, GLenum p
 void
 ppb_opengles2_query_get_query_objectuiv_ext(PP_Resource context, GLuint id, GLenum pname,
                                             GLuint *params);
-
-#endif // FPP_PPB_OPENGLES2_H
