@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013-2015  Rinat Ibragimov
+ * Copyright © 2013-2017  Rinat Ibragimov
  *
  * This file is part of FreshPlayerPlugin.
  *
@@ -22,19 +22,16 @@
  * SOFTWARE.
  */
 
-#include "ppb_pdf.h"
-#include <stdlib.h>
-#include <libgen.h>
-#include <glib.h>
-#include "trace.h"
-#include "pp_resource.h"
-#include "reverse_constant.h"
-#include "ppb_flash_font_file.h"
-#include "ppb_image_data.h"
-#include "ppb_var.h"
-#include "np_entry.h"
+#include "config_priv.h"
 #include "pp_interface.h"
-
+#include "ppb_flash_font_file.h"
+#include "ppb_pdf.h"
+#include "reverse_constant.h"
+#include "trace_core.h"
+#include "trace_helpers.h"
+#include <glib.h>
+#include <libgen.h>
+#include <stdlib.h>
 
 static GMappedFile  *natives_blob = NULL;
 static GMappedFile  *snapshot_blob = NULL;
@@ -134,7 +131,7 @@ ppb_pdf_get_v8_external_snapshot_data(PP_Instance instance, const char **natives
                                       int *snapshot_size_out)
 {
     if (!natives_blob || !snapshot_blob) {
-        gchar *tmp = g_strdup(np_entry_get_module_file_name());
+        gchar *tmp = g_strdup(fpp_config_get_plugin_path());
         gchar *module_dir = dirname(tmp);
         gchar *natives_path = g_strdup_printf("%s/natives_blob.bin", module_dir);
         gchar *snapshot_path = g_strdup_printf("%s/snapshot_blob.bin", module_dir);
