@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013-2015  Rinat Ibragimov
+ * Copyright © 2013-2017  Rinat Ibragimov
  *
  * This file is part of FreshPlayerPlugin.
  *
@@ -22,12 +22,21 @@
  * SOFTWARE.
  */
 
-#ifndef FPP_PPB_UDP_SOCKET_H
-#define FPP_PPB_UDP_SOCKET_H
+#pragma once
 
-#include <ppapi/c/private/ppb_udp_socket_private.h>
+#include "pp_resource.h"
 #include <ppapi/c/ppb_udp_socket.h>
+#include <ppapi/c/private/ppb_udp_socket_private.h>
 
+struct pp_udp_socket_s {
+    COMMON_STRUCTURE_FIELDS
+    int                             sock;
+    int                             bound;
+    int                             seen_eof;
+    int                             destroyed;
+    struct PP_NetAddress_Private    addr;
+    struct PP_NetAddress_Private    addr_from;
+};
 
 PP_Resource
 ppb_udp_socket_create(PP_Instance instance_id);
@@ -88,5 +97,3 @@ ppb_udp_socket_send_to_1_0(PP_Resource udp_socket, const char *buffer, int32_t n
 
 void
 ppb_udp_socket_close(PP_Resource udp_socket);
-
-#endif // FPP_PPB_UDP_SOCKET_H
