@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013-2015  Rinat Ibragimov
+ * Copyright © 2013-2017  Rinat Ibragimov
  *
  * This file is part of FreshPlayerPlugin.
  *
@@ -22,16 +22,13 @@
  * SOFTWARE.
  */
 
-#ifndef FPP_URI_PARSER_URI_PARSER_H
-#define FPP_URI_PARSER_URI_PARSER_H
+#pragma once
 
-#include <ppapi/c/dev/ppb_url_util_dev.h>
 #include <glib.h>
+#include <ppapi/c/dev/ppb_url_util_dev.h>
 
 void
 uri_parser_parse_uri(const char *s, struct PP_URLComponents_Dev *components);
 
 gchar *
 uri_parser_merge_uris(const char *base_uri, const char *rel_uri);
-
-#endif // FPP_URI_PARSER_URI_PARSER_H
