@@ -1,18 +1,13 @@
-#ifndef FPP_TESTS_COMMON_H
-#define FPP_TESTS_COMMON_H
+#pragma once
 
-#include <src/pp_resource.h>
+#include <ppapi/c/pp_instance.h>
 
 #ifndef TEST_DATA_DIR
 #error TEST_DATA_DIR not defined
 #endif
 
-
 PP_Instance
 create_instance(void);
 
 void
 destroy_instance(PP_Instance instance);
-
-
-#endif // FPP_TESTS_COMMON_H
